r47196 - use group14

hawkowl-TA+aISz0psMTMxyoc4vAAJOcrHinNvQL0E9HWUfgJXw@public.gmane.org Sat, 9 Apr 2016 02:08:49 -0600 (MDT)
Newsgroups gmane.comp.python.twisted.commits
Message-ID <[email protected]>
Author: hawkowl
Date: Sat Apr  9 02:08:45 2016
New Revision: 47196

Added:
   branches/unbork-openssh-8279-2/twisted/conch/topfiles/8279.misc
Modified:
   branches/unbork-openssh-8279-2/twisted/conch/test/test_ssh.py

Log:
use group14

Modified: branches/unbork-openssh-8279-2/twisted/conch/test/test_ssh.py
==============================================================================
--- branches/unbork-openssh-8279-2/twisted/conch/test/test_ssh.py	(original)
+++ branches/unbork-openssh-8279-2/twisted/conch/test/test_ssh.py	Sat Apr  9 02:08:45 2016
@@ -364,12 +364,12 @@
                 C{(generator, prime)} tupple.
             """
             # In these tests, we hardwire the prime values to those defined by
             # the diffie-hellman-group1-sha1 key exchange algorithm, to avoid
             # requiring a moduli file when running tests.
             # See OpenSSHFactory.getPrimes.
             return {
                 2048: [
-                    _kex.getDHGeneratorAndPrime('diffie-hellman-group1-sha1')]
+                    _kex.getDHGeneratorAndPrime('diffie-hellman-group14-sha1')]
             }
 
         def getService(self, trans, name):
@@ -364,12 +364,12 @@
             """
             # In these tests, we hardwire the prime values to those defined by
-            # the diffie-hellman-group1-sha1 key exchange algorithm, to avoid
+            # the diffie-hellman-group14-sha1 key exchange algorithm, to avoid
             # requiring a moduli file when running tests.
             # See OpenSSHFactory.getPrimes.